@@ -4,9 +4,9 @@ from sqlconstructor import SqlContainer
 
 @pytest.mark.SqlContainer
 def test_add():
-    assert SqlContainer('a') + 'b' == 'ab'
+    assert str(SqlContainer('a') + 'b') == 'ab'
 
 
 @pytest.mark.SqlContainer
 def test_radd():
-    assert 'b' + SqlContainer('a') == 'ba'
+    assert str('b' + SqlContainer('a')) == 'ba'
