@@ -5,7 +5,7 @@ from sqlconstructor.constants import AND_MODE
 
 @pytest.mark.SqlFilters
 def test_add():
-    assert SqlFilters({'a': 1, 'b': 2}) + 'c' == '\n'.join(
+    assert str(SqlFilters({'a': 1, 'b': 2}) + 'c') == '\n'.join(
         (
             'a=1',
             AND_MODE,
@@ -16,7 +16,7 @@ def test_add():
 
 @pytest.mark.SqlFilters
 def test_radd():
-    assert 'c' + SqlFilters({'a': 1, 'b': 2}) == '\n'.join(
+    assert str('c' + SqlFilters({'a': 1, 'b': 2})) == '\n'.join(
         (
             'ca=1',
             AND_MODE,
